===============================================================
BORIS (Behavioral Observation Research Interactive Software)
===============================================================

.. image:: https://github.com/olivierfriard/BORIS/blob/master/boris/icons/logo_boris.png?raw=true
 :target: https://www.boris.unito.it


BORIS is an easy-to-use event logging software for video/audio coding or live observations.

BORIS is a free and open-source software available for GNU/Linux and Windows.
You can not longer run BORIS natively on MacOS (since v.8). Some alternatives to run the last version of BORIS are available, see `BORIS on MacOS <http://www.boris.unito.it/pages/download_mac>`_.

It provides also some analysis tools like time budget and some plotting functions.

The BORIS paper has more than `1400 citations in peer-reviewed scientific publications <http://www.boris.unito.it/pages/citations.html>`_.

See http://www.boris.unito.it


.. image:: https://img.shields.io/badge/Made%20with-Python-1f425f.svg
 :target: https://www.python.org/

.. image:: https://img.shields.io/pypi/pyversions/boris-behav-obs

.. image:: https://img.shields.io/pypi/l/boris-behav-obs

.. image:: https://static.pepy.tech/personalized-badge/boris-behav-obs?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads
 :target: https://pepy.tech/project/boris-behav-obs

.. image:: https://img.shields.io/github/commit-activity/m/olivierfriard/BORIS

.. image:: https://img.shields.io/pypi/v/boris-behav-obs.svg
 :target: https://pypi.org/project/boris-behav-obs/




Documentation
-----------------------------------------------------------------------


The documentation provides a good starting point for learning how to use BORIS: http://boris.readthedocs.io/

Some video tutorials are available: http://www.boris.unito.it/pages/video_tutorials.html





Bug reports and feature requests
-----------------------------------------------------------------------

To search for bugs, report them or request a feature, please use the github tracker:
https://github.com/olivierfriard/BORIS/issues





Citing BORIS
-----------------------------------------------------------------------

Please acknowledge and cite the use of this software and its authors when
results are used in publications or published elsewhere. You can use the
following BibTex entry

::

    @article {MEE3:MEE312584,
    author = {Friard, Olivier and Gamba, Marco},
    title = {BORIS: a free, versatile open-source event-logging software for video/audio coding and live observations},
    journal = {Methods in Ecology and Evolution},
    issn = {2041-210X},
    url = {http://dx.doi.org/10.1111/2041-210X.12584},
    doi = {10.1111/2041-210X.12584},
    pages = {1324--1330},
    keywords = {behavioural analysis, behaviour coding, coding scheme, ethology, observational data, ttime-budget},
    year = {2016},
    }


You can also send us a nice postcard! See the `user testimonials <http://www.boris.unito.it/pages/postcards.html>`_








Licence
-----------------------------------------------------------------------


::

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.


Distributed with a `GPL v.3 license <LICENSE.TXT>`_

Copyright (C) 2012-2023 Olivier Friard




